@@ -11,7 +11,6 @@ import sys
 from jinja2 import FileSystemLoader, Environment
 import nbformat
 from jupyter_server.base.handlers import JupyterHandler, APIHandler
-from jupyter_server_mathjax.app import STATIC_ASSETS_PATH
 from jupyter_server.utils import url_path_join
 from jupyter_server.log import log_request
 import requests
@@ -51,8 +50,7 @@ class NbdimeHandler(JupyterHandler):
             'savable': fn is not None,
             'baseUrl': self.nbdime_base_url,
             'hideUnchanged': self.params.get('hide_unchanged', True),
-            'mathjaxUrl': self.mathjax_url,
-            'mathjaxConfig': self.mathjax_config,
+            'collapseIdentical': self.params.get('identical_lines_margin', 2),
         }
         if fn:
             # For reference, e.g. if user wants to download file
@@ -192,6 +190,7 @@ class MainMergeHandler(NbdimeHandler):
         args['base'] = self.get_argument('base', '')
         args['local'] = self.get_argument('local', '')
         args['remote'] = self.get_argument('remote', '')
+        args['showBase'] = self.params.get('show_base', True)
         self.write(self.render_template('merge.html',
                     config_data=args,
                    ))
@@ -204,10 +203,12 @@ class MainMergetoolHandler(NbdimeHandler):
             args['base'] = self.params['mergetool_args']['base']
             args['local'] = self.params['mergetool_args']['local']
             args['remote'] = self.params['mergetool_args']['remote']
+            args['showBase'] = self.params.get('show_base', True)
         else:
             args['base'] = self.get_argument('base', '')
             args['local'] = self.get_argument('local', '')
             args['remote'] = self.get_argument('remote', '')
+            args['showBase'] = self.params.get('show_base', True)
         self.write(self.render_template('mergetool.html',
                     config_data=args,
                    ))
@@ -312,7 +313,7 @@ class ApiCloseHandler(NbdimeHandler, APIHandler):
                 self.application.exit_code = json.loads(self.request.body).get('exitCode', fallback)
             except json.JSONDecodeError:
                 self.application.exit_code = fallback
-        
+
         if isinstance(self.application.exit_code, str):
             self.application.exit_code = int(self.application.exit_code, 10)
 
@@ -366,9 +367,6 @@ def make_app(**params):
         (r'/api/merge', ApiMergeHandler, params),
         (r'/api/store', ApiMergeStoreHandler, params),
         (r'/api/closetool', ApiCloseHandler, params),
-        (r'/nb-static/mathjax/(.*)', web.StaticFileHandler, {
-            'path': STATIC_ASSETS_PATH
-        })
         # Static handler will be added automatically
     ]
     if base_url != '/':
@@ -388,7 +386,6 @@ def make_app(**params):
         'template_path': [template_path],
         'base_url': base_url,
         'jinja2_env': env,
-        'mathjax_url': prefix + '/nb-static/mathjax/MathJax.js',
         'local_hostnames': ['localhost', '127.0.0.1'],
         'cookie_secret': base64.encodebytes(os.urandom(32)), # Needed even for an unsecured server.
     }
